#!/bin/bash
#
#  $Id: builddmg.sh.in 1563 2006-12-26 06:06:04Z edmanm $
# 
#  Vidalia is distributed under the following license:
#
#  Copyright (C) 2006,  Matt Edman, Justin Hipple
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
#  02110-1301, USA.
#################################################################

# Make sure enough arguments were supplied
if [ "$#" -ne 2 ]
then
  echo "Usage: $0 <srcdir> <files to include>"
  exit 1
fi

# Make sure the source directory exists
srcdir=$1
if [ ! -d "$srcdir" ]
then
  echo "Specified source directory doesn't exit: $srcdir"
  exit 1
fi
echo "Source Directory: $srcdir"

# Determine OSX Version and map version to name
if [ -x /usr/bin/sw_vers ]
then
  # This is poor, yet functional.  We don't care about the 3rd number in
  # the OS version
  OSVER=`/usr/bin/sw_vers | grep ProductVersion | cut -f2 | cut -d"." -f1,2`
  case "$OSVER" in
    "10.5") OS="leopard";;
    "10.4") OS="tiger";;
    "10.3") OS="panther";;
    "10.2") OS="jaguar";;
    "10.1") OS="puma";;
    "10.0") OS="cheetah";;
         *) OS="unknown";;
  esac
else
  OS="unknown"
fi

# Set the location of the temporary files
BUILD_DIR=/tmp/vidalia-osx-$$
# Set the Vidalia version
VERSION="0.0.12-svn"
# Set the name of the output .dmg file
DMG="vidalia-$VERSION-$OS.dmg"

# Get the rest of the command-line arguments
filelist=$2
echo "Files to copy: $filelist"
echo "Destination Disk Image: $DMG"
volname=`echo "$DMG" | sed -e "s/.*\///" | sed -e "s/.dmg//"`
echo "Volume Name: $volname"

# Create the temporary directory
mkdir $BUILD_DIR || exit 1

# Copy over the specified files into the disk image
for file in $filelist
do
  echo "Copying $srcdir/$file to $BUILD_DIR/$file"
  cp -r "$srcdir/$file" "$BUILD_DIR/$file"
done

# Create the disk image
hdiutil create -format UDZO -srcfolder "$BUILD_DIR" -volname "$volname" "$DMG"
rm -rf "$BUILD_DIR"

